const axios = require('axios');

const ElasticService = {
  get: async function (config, data) {
    try {
      data = encodeURIComponent(data);
      console.log(`Querying ElasticSearch - ${config.api}?q=id:${data}`);
      const res = await axios.get(`${config.api}?q=id:${data}`);
      console.log("ElasticSearch returned: " + res.status);
      if (res.data) {
        return {data: res.data, status: res.status};
      } else {
        return {data: {}, status: res.status};
      }
    } catch (e) {
      return {data: {}, status: e.message};
    }
  },

  // elasticsearch pagination params are 'from' and 'size'
  // I don't think that the page function has any purpose in the solr query?

  search: async function (config, {start: start, page: page, searchParam: searchParam, text: text, facets: facets, facetLimit: facetLimit}) {
    try {
      let param = `select?q=`;      
      if (text === '' || !text ) {
        text = '*';
      }
      let escText = text.replace(':', "\\:");
      let query = {
        match: { "*": text }
      };

      //`q=${searchParam}:${escText}&from=${start}`;
      console.log(`Querying ElasticSearch - ${config.api} ${JSON.stringify(query)}`);
      const res = await axios.post(config.api, { query: query });
      console.log("ElasticSearch returned: " + res.status);
      if (res.data) {
        return {data: res.data['response'], status: res.status};
      } else {
        console.log("Empty response");
        return {data: [], status: res.status};
      }
    } catch (e) {
      return {data: [], status: e.message};
    }
  }
};

module.exports = ElasticService;
